@@ -8,14 +8,8 @@ from lxml import etree
 import icat
 import icat.dumpfile
 from icat.query import Query
-try:
-    utc = datetime.timezone.utc
-except AttributeError:
-    try:
-        from suds.sax.date import UtcTimezone
-        utc = UtcTimezone()
-    except ImportError:
-        utc = None
+
+utc = datetime.timezone.utc
 
 
 # ------------------------------------------------------------
@@ -68,7 +62,15 @@ class XMLDumpFileReader(icat.dumpfile.DumpFileReader):
         else:
             # object is referenced by attributes.
             attrs = set(element.keys()) - {'id'}
-            conditions = { a: "= '%s'" % element.get(a) for a in attrs }
+            conditions = dict()
+            for attr in attrs:
+                if attr.endswith(".ref"):
+                    ref = element.get(attr)
+                    robj = self.client.searchUniqueKey(ref, objindex)
+                    attr = "%s.id" % attr[:-4]
+                    conditions[attr] = "= %d" % robj.id
+                else:
+                    conditions[attr] = "= '%s'" % element.get(attr)
             query = Query(self.client, objtype, conditions=conditions)
             return self.client.assertedSearch(query)[0]
 
@@ -185,13 +187,10 @@ class XMLDumpFileWriter(icat.dumpfile.DumpFileWriter):
                     # dependency of server settings in the dumpfile.
                     # Assume v.isoformat() to have a valid timezone
                     # suffix.
-                    if utc:
-                        v = v.astimezone(utc)
-                    v = v.isoformat()
+                    v = v.astimezone(tz=utc).isoformat()
                 else:
-                    # v has no timezone info, assume it to be UTC, append
-                    # the corresponding timezone suffix.
-                    v = v.isoformat() + 'Z'
+                    # v has no timezone info, assume it to be UTC.
+                    v = v.replace(tzinfo=utc).isoformat()
             else:
                 v = str(v)
             etree.SubElement(d, attr).text = v
@@ -208,7 +207,7 @@ class XMLDumpFileWriter(icat.dumpfile.DumpFileWriter):
 
     def head(self):
         """Write a header with some meta information to the data file."""
-        date = datetime.datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%S+00:00")
+        date = datetime.datetime.now(tz=utc).isoformat()
         head = etree.Element("head")
         etree.SubElement(head, "date").text = date
         etree.SubElement(head, "service").text = self.client.url
