@@ -7,7 +7,10 @@ uses the internal API icat.dumpfile.
 
 import filecmp
 import io
-from lxml import etree
+try:
+    from lxml import etree
+except ImportError:
+    etree = None
 import pytest
 try:
     from pytest_dependency import depends
@@ -18,10 +21,9 @@ import icat
 import icat.config
 from icat.dump_queries import *
 from icat.dumpfile import open_dumpfile
-import icat.dumpfile_xml
-import icat.dumpfile_yaml
 from icat.query import Query
-from conftest import (getConfig, get_reference_dumpfile, callscript,
+from conftest import (getConfig, require_dumpfile_backend,
+                      get_reference_dumpfile, callscript,
                       filter_file, yaml_filter, xml_filter)
 
 
@@ -37,7 +39,6 @@ backends = {
         'filter': yaml_filter,
     },
 }
-assert backends.keys() == icat.dumpfile.Backends.keys()
 
 # The following cases are tuples of a backend and a file type (regular
 # file, stdin/stdout, in-memory stream).  They are used for both,
@@ -54,27 +55,42 @@ ocases = cases
 # to verify that object relations are kept intact after an icatdump /
 # icatingest cycle.
 queries = [
-    ("Datafile.name <-> Dataset <-> Investigation [name='10100601-ST']",
-     ['e208339.dat', 'e208339.nxs', 'e208341.dat', 'e208341.nxs']),
-    ("SELECT p.numericValue FROM DatasetParameter p "
-     "JOIN p.dataset AS ds JOIN ds.investigation AS i JOIN p.type AS t "
-     "WHERE i.name = '10100601-ST' AND ds.name = 'e208339' "
-     "AND t.name = 'Magnetic field'",
-     [7.3]),
-    ("SELECT ds.name FROM Dataset ds "
-     "JOIN ds.dataCollectionDatasets AS dcds "
-     "JOIN dcds.dataCollection AS dc JOIN dc.jobsAsOutput AS j "
-     "WHERE j.id IS NOT NULL",
-     ["e208947"]),
-    ("SELECT df.name FROM Datafile df "
-     "JOIN df.dataCollectionDatafiles AS dcdf "
-     "JOIN dcdf.dataCollection AS dc JOIN dc.jobsAsInput AS j "
-     "WHERE j.id IS NOT NULL",
-     ["e208945.nxs"]),
-    ("SELECT COUNT(dc) FROM DataCollection dc "
-     "JOIN dc.dataCollectionDatasets AS dcds JOIN dcds.dataset AS ds "
-     "WHERE ds.name = 'e201215'",
-     [1]),
+    pytest.param(
+        "Datafile.name <-> Dataset <-> Investigation [name='10100601-ST']",
+        ['e208339.dat', 'e208339.nxs', 'e208341.dat', 'e208341.nxs'],
+        id="df.name"
+    ),
+    pytest.param(
+        "SELECT p.numericValue FROM DatasetParameter p "
+        "JOIN p.dataset AS ds JOIN ds.investigation AS i JOIN p.type AS t "
+        "WHERE i.name = '10100601-ST' AND ds.name = 'e208339' "
+        "AND t.name = 'Magnetic field'",
+        [7.3],
+        id="param.name"
+    ),
+    pytest.param(
+        "SELECT ds.name FROM Dataset ds "
+        "JOIN ds.dataCollectionDatasets AS dcds "
+        "JOIN dcds.dataCollection AS dc JOIN dc.jobsAsOutput AS j "
+        "WHERE j.id IS NOT NULL",
+        ["e208947"],
+        id="jobout_ds.name"
+    ),
+    pytest.param(
+        "SELECT df.name FROM Datafile df "
+        "JOIN df.dataCollectionDatafiles AS dcdf "
+        "JOIN dcdf.dataCollection AS dc JOIN dc.jobsAsInput AS j "
+        "WHERE j.id IS NOT NULL",
+        ["e208945.nxs"],
+        id="jobin_df.name"
+    ),
+    pytest.param(
+        "SELECT COUNT(dc) FROM DataCollection dc "
+        "JOIN dc.dataCollectionDatasets AS dcds JOIN dcds.dataset AS ds "
+        "WHERE ds.name = 'e201215'",
+        [1],
+        id="dc.count"
+    ),
 ]
 
 # ======== function equivalents to icatdump and icatingest ===========
@@ -128,6 +144,7 @@ def test_ingest(ingestcase, client):
     """Restore the ICAT content from a dumpfile.
     """
     backend, filetype = ingestcase
+    require_dumpfile_backend(backend)
     refdump = backends[backend]['refdump']
     if filetype == 'FILE':
         icatingest(client, refdump, backend)
@@ -141,6 +158,8 @@ def test_ingest(ingestcase, client):
         icatingest(client, stream, backend)
         stream.close()
     elif filetype == 'ETREE':
+        if etree is None:
+            pytest.skip("Need lxml")
         with refdump.open("rb") as f:
             icatdata = etree.parse(f)
         icatingest(client, icatdata, backend)
@@ -152,6 +171,7 @@ def test_check_content(ingestcheck, client, tmpdirsec, case):
     """Dump the content and check that we get the reference dump file back.
     """
     backend, filetype = case
+    require_dumpfile_backend(backend)
     refdump = backends[backend]['refdump']
     fileext = backends[backend]['fileext']
     dump = tmpdirsec / ("dump" + fileext)
